# Copyright (c) Jeremías Casteglione <jrmsdev@gmail.com>
# See LICENSE file.

# ~ from _sadm.utils import systemd

__all__ = ['deploy']

# run as root at first pass
sumode = 'pre'

def deploy(env):
	pass
	# ~ systemd.restart('netfilter-persistent')
